/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { FC, ReactNode } from 'react';
import React, { memo } from 'react';
import styled from 'styled-components';
import { EuiFlexGroup, EuiFlexItem } from '@elastic/eui';
import { euiThemeVars } from '@kbn/ui-theme';

import type { MlSummaryJob } from '@kbn/ml-plugin/public';
import * as i18n from './translations';

import { isJobStarted } from '../../../../../common/machine_learning/helpers';

import { MlJobLink } from '../ml_job_link/ml_job_link';
import { MlAuditIcon } from '../ml_audit_icon';
import { MlJobStatusBadge } from '../ml_job_status_badge';

const Wrapper = styled.div`
  overflow: hidden;
  margin-bottom: ${euiThemeVars.euiSizeS};
`;

const MlJobItemComponent: FC<{
  job: MlSummaryJob;
  switchComponent: ReactNode;
}> = ({ job, switchComponent, ...props }) => {
  const isStarted = isJobStarted(job.jobState, job.datafeedState);

  return (
    <Wrapper {...props}>
      <div>
        <MlJobLink jobId={job.id} jobName={job.customSettings?.security_app_display_name} />
        <MlAuditIcon message={job.auditMessage} />
      </div>
      <EuiFlexGroup justifyContent="flexStart">
        <EuiFlexItem grow={false} style={{ marginRight: '0' }}>
          <MlJobStatusBadge job={job} />
        </EuiFlexItem>
        <EuiFlexItem grow={false}>{switchComponent}</EuiFlexItem>
        <EuiFlexItem grow={false} style={{ marginLeft: '0' }} data-test-subj="mlJobActionLabel">
          {isStarted ? i18n.ML_STOP_JOB_LABEL : i18n.ML_RUN_JOB_LABEL}
        </EuiFlexItem>
      </EuiFlexGroup>
    </Wrapper>
  );
};

export const MlJobItem = memo(MlJobItemComponent);
