/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */
import { EuiEmptyPrompt, EuiPanel, EuiToolTip } from '@elastic/eui';
import React from 'react';
import type { EntityType } from '../../../../common/search_strategy';
import { useCheckSignalIndex } from '../../../detections/containers/detection_engine/alerts/use_check_signal_index';
import type { inputsModel } from '../../../common/store';
import { RiskScoreHeaderTitle } from '../risk_score_onboarding/risk_score_header_title';
import { HeaderSection } from '../../../common/components/header_section';
import { EntityAnalyticsLearnMoreLink } from '../risk_score_onboarding/entity_analytics_doc_link';
import { RiskScoreEnableButton } from '../risk_score_onboarding/risk_score_enable_button';
import * as i18n from './translations';

const EnableRiskScoreComponent = ({
  isDeprecated,
  isDisabled,
  entityType,
  refetch,
  timerange,
}: {
  isDeprecated: boolean;
  isDisabled: boolean;
  entityType: EntityType;
  refetch: inputsModel.Refetch;
  timerange: {
    from: string;
    to: string;
  };
}) => {
  const { signalIndexExists } = useCheckSignalIndex();
  if (!isDeprecated && !isDisabled) {
    return null;
  }

  const text = isDeprecated
    ? {
        cta: i18n.UPGRADE_RISK_SCORE(entityType),
        body: i18n.UPGRADE_RISK_SCORE_DESCRIPTION,
      }
    : {
        cta: i18n.ENABLE_RISK_SCORE(entityType),
        body: i18n.ENABLE_RISK_SCORE_DESCRIPTION(entityType),
      };

  return (
    <EuiPanel hasBorder>
      <HeaderSection title={<RiskScoreHeaderTitle riskScoreEntity={entityType} />} titleSize="s" />
      <EuiEmptyPrompt
        title={<h2>{text.cta}</h2>}
        body={
          <>
            {text.body}
            {` `}
            <EntityAnalyticsLearnMoreLink />
          </>
        }
        actions={
          <EuiToolTip content={!signalIndexExists ? i18n.ENABLE_RISK_SCORE_POPOVER : null}>
            <RiskScoreEnableButton
              disabled={!signalIndexExists}
              refetch={refetch}
              riskScoreEntity={entityType}
              timerange={timerange}
            />
          </EuiToolTip>
        }
      />
    </EuiPanel>
  );
};

export const EnableRiskScore = React.memo(EnableRiskScoreComponent);
EnableRiskScore.displayName = 'EnableRiskScore';
